@@ -1,5 +1,5 @@
 package Starch::Store::Catalyst::Plugin::Session;
-$Starch::Store::Catalyst::Plugin::Session::VERSION = '0.02';
+$Starch::Store::Catalyst::Plugin::Session::VERSION = '0.03';
 =head1 NAME
 
 Starch::Store::Catalyst::Plugin::Session - Starch storage backend using
@@ -138,17 +138,19 @@ sub _build_store {
     return $store;
 }
 
+=head1 METHODS
+
 =head2 set
 
-Set L<Starch::Store/set>.  Calls C<store_session_data> on L</store>.
+See L<Starch::Store/set>.  Calls C<store_session_data> on L</store>.
 
 =head2 get
 
-Set L<Starch::Store/get>.  Calls C<get_session_data> on L</store>.
+See L<Starch::Store/get>.  Calls C<get_session_data> on L</store>.
 
 =head2 remove
 
-Set L<Starch::Store/remove>.  Calls C<delete_session_data> on L</store>.
+See L<Starch::Store/remove>.  Calls C<delete_session_data> on L</store>.
 
 =cut
 
@@ -157,7 +159,7 @@ sub set {
 
     local $Carp::Internal{ (__PACKAGE__) } = 1;
 
-    $self->store->store_session_data( $id, $data );
+    $self->store->store_session_data( "session:$id", $data );
 
     return;
 }
@@ -167,7 +169,7 @@ sub get {
 
     local $Carp::Internal{ (__PACKAGE__) } = 1;
 
-    return $self->store->get_session_data( $id );
+    return $self->store->get_session_data( "session:$id" );
 }
 
 sub remove {
@@ -175,7 +177,7 @@ sub remove {
 
     local $Carp::Internal{ (__PACKAGE__) } = 1;
 
-    $self->store->delete_session_data( $id );
+    $self->store->delete_session_data( "session:$id" );
 
     return;
 }
